@@ -1,22 +1,22 @@
 /*  message.c - external control for alsaplayer
  *  Copyright (C) 2002 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  AlsaPlayer is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- *
- *  $Id: message.c,v 1.36 2003/09/05 09:47:48 adnans Exp $
+ *  $Id: message.c 1344 2010-11-07 20:38:05Z dominique_libre $
  *
  */ 
 #include "message.h"
@@ -83,7 +83,7 @@ ap_key_t *ap_key_new(const char *key_id)
 		memset(key, 0, sizeof(ap_key_t));
 		if (strlen(key_id) > KEYID_LEN) {
 			strncpy(key->key_id, key_id, KEYID_LEN-1);
-			key->key_id[KEYID_LEN] = 0;
+			key->key_id[KEYID_LEN-1] = 0;
 		} else {
 			strcpy(key->key_id, key_id);
 		}	
@@ -209,7 +209,7 @@ ap_message_t *ap_message_receive(int fd)
 }
 
 
-int ap_message_add_float(ap_message_t *msg, char *key, float val)
+int ap_message_add_float(ap_message_t *msg, const char *key, float val)
 {
 	ap_key_t *new_key;
 
@@ -226,7 +226,7 @@ int ap_message_add_float(ap_message_t *msg, char *key, float val)
 }
 
 
-int ap_message_add_int32(ap_message_t *msg, char *key, int32_t val)
+int ap_message_add_int32(ap_message_t *msg, const char *key, int32_t val)
 {
 	ap_key_t *new_key;
 
@@ -244,7 +244,7 @@ int ap_message_add_int32(ap_message_t *msg, char *key, int32_t val)
 }
 
 
-ap_key_t *ap_message_find_key(ap_message_t *msg, char *key, int32_t key_type)
+ap_key_t *ap_message_find_key(ap_message_t *msg, const char *key, int32_t key_type)
 {
 	ap_key_t *current;
 	
@@ -262,7 +262,7 @@ ap_key_t *ap_message_find_key(ap_message_t *msg, char *key, int32_t key_type)
 }
 
 
-float *ap_message_find_float(ap_message_t *msg, char *key_id)
+float *ap_message_find_float(ap_message_t *msg, const char *key_id)
 {
 	ap_key_t *key;
 
@@ -273,7 +273,7 @@ float *ap_message_find_float(ap_message_t *msg, char *key_id)
 }
 
 
-int32_t *ap_message_find_int32(ap_message_t *msg, char *key_id)
+int32_t *ap_message_find_int32(ap_message_t *msg, const char *key_id)
 {
 	ap_key_t *key;
 
@@ -284,7 +284,7 @@ int32_t *ap_message_find_int32(ap_message_t *msg, char *key_id)
 }
 
 
-char *ap_message_find_string(ap_message_t *msg, char *key_id)
+char *ap_message_find_string(ap_message_t *msg, const char *key_id)
 {
 	ap_key_t *key;
 
@@ -295,7 +295,7 @@ char *ap_message_find_string(ap_message_t *msg, char *key_id)
 }
 
 
-int ap_message_add_string(ap_message_t *msg, char *key_id, const char *val)
+int ap_message_add_string(ap_message_t *msg, const char *key_id, const char *val)
 {
 	ap_key_t *new_key;
 	char *str;
@@ -381,7 +381,7 @@ int ap_find_session(char *session_name, int *session)
 
 	pwd = getpwuid(geteuid());
 
-	sprintf(username, pwd == NULL ? "anonymous" : pwd->pw_name);
+	sprintf(username, "%s", pwd == NULL ? "anonymous" : pwd->pw_name);
 
 	sprintf(test_path, "alsaplayer_%s_", username);
 
@@ -1119,6 +1119,64 @@ int ap_set_string_set_int(int session, int32_t cmd, const char* string, int val)
 	return 0;
 }        
 
+int ap_get_playlist(int session, int *argc, char ***the_list) {
+	int fd;
+	char **list;
+	ap_message_t *msg, *reply;
+	int *result, nritems, c;
+	char strnum[64];
+	char *res;
+	
+	fd = ap_connect_session(session);
+	if (fd < 0)
+		return 0;
+	msg = ap_message_new();
+	msg->header.cmd = AP_GET_PLAYLIST;
+	
+	ap_message_send(fd, msg);
+	ap_message_delete(msg);
+	msg = NULL;
+
+	reply = ap_message_receive(fd);
+	close(fd);
+	
+	if ((result = ap_message_find_int32(reply, "items"))) {
+		nritems = *result;
+		if (nritems > 0) {
+			*argc = nritems;
+		} else {
+			*argc = 0;
+			ap_message_delete(reply);
+			return 1;
+		}	
+		list = (char **)malloc(sizeof(char *) * nritems);
+		if (!list) {
+			ap_message_delete(reply);
+			return 0;
+		}	
+		for (c=0; c < nritems; c++) {
+			sprintf(strnum, "%d", c+1);
+			res = ap_message_find_string(reply, strnum);
+			if (res) {
+				list[c] = strdup(res);
+				if (!list[c]) {
+					printf("error!");
+					ap_message_delete(reply);
+					// XXX memory leak XXX
+					return 0;
+				}
+				//printf("Got string (%s): %s\n", strnum, list[c]);
+			}
+		}
+		*the_list = list;
+		ap_message_delete(reply);
+		return 1;
+	}
+	ap_message_delete(reply);
+	return 0;
+
+}
+
 int ap_insert(int session, const char* path, int val) {
     return ap_set_string_set_int(session, AP_INSERT, path, val);
 }
