@@ -2,27 +2,28 @@
  *   Copyright (C) 2002 Evgeny Chukreev <codedj@echo.ru>
  *   Copyright (C) 2002 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+ *  This file is part of AlsaPlayer.
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  AlsaPlayer is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *   $Id: http.c 1063 2007-02-01 15:29:18Z dominique_libre $
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
+ *   $Id: http.c 1344 2010-11-07 20:38:05Z dominique_libre $
  *
  */
 
 #include "config.h"
 
-#include <malloc.h>
+#include <stdlib.h>
 #include <netdb.h>
 #include <stdlib.h>
 #include <string.h>
@@ -477,7 +478,8 @@ static int reconnect (http_desc_t *desc, char *redirect)
     char request [2048];
     char response [10240];
     char *s;
-    int error, error_len;
+    int error;
+    socklen_t error_len;
     struct hostent *hp;
     struct sockaddr_in address;
     fd_set set;
